package simulation_Lab06Version;

import imagePackage.RasterImage;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

/**
 * This class encapsulates functionality for drawing successive frames of an animation.
 * The animated scene is specified by an animation model that is provided. 
 * This class encapsulates functionality as an ActionListener, so that objects of
 * this type can listen for events that trigger the drawing of the successive frames.
 * 
 * @author mb
 * 
 */
public class AnimationController implements ActionListener
{

	// attributes that concern the drawing environment
	private RasterImage theFrameImage;
	private Graphics2D graphics2D;

	// attribute for what is drawn on-screen (encapsulates the sprite(s))
	private Model animationModel;

	public AnimationController(Model model)
	{

		// initialize the attribute(s) that concern that which is drawn on each
		// frame
		animationModel = model;

		// assign the value of the attribute by invoking required constructor
		// and invoking required methods
		this.theFrameImage = new RasterImage(model.getWorldWidth(),
				model.getWorldHeight());
		theFrameImage.show();
		this.theFrameImage.setTitle(this.getClass().getName() + " "
				+ UtilityClass.getTimestamp());

		// assign the value of the attribute by invoking appropriate accessor.
		graphics2D = theFrameImage.getGraphics2D();
	}

	public void actionPerformed(ActionEvent ae)
	{
		theFrameImage.setAllPixelsToAColor(Color.WHITE);

		// *****
		// now we draw the new frame; delegate to the animation model and ask it
		// to draw the next frame on the passed graphics2D object. The object
		// encapsulates the operations to update the position of the anchor (for
		// the next frame)
		animationModel.drawNewFrame(graphics2D);

		// *****
		// the graphics2D object has been updated, so signal that the window
		// manager needs to repaint it.
		theFrameImage.repaint();
	}

}
