package simulation_Lab06Version;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.Point;
import java.awt.Shape;
import java.awt.geom.Ellipse2D;

/**
 * This class encapsulates a sprite which is a circle of diameter 30 units.
 * The sprite is initially black and lightens with time; when the colour reaches white,
 * the process starts over. The sprite's initial position is at the top left. For each frame,
 * the sprite moves 1 unit down and 1 unit to the right, wrapping around the
 * canvas when the boundaries are encountered.  To this basic move a uniformly
 * distributed random perturbation in [-10,10] in vertical and horizontal displacement are added.
 * 
 * @author mb
 * 
 */
public class BasicSprite implements Sprite{

	// attribute for the on-screen sprite
	private Shape dot;
	// the following attributes are needed to store information about the sprite
	// we are drawing
	private Point anchorPoint;
	private final int DIA = 10 * 3;
	private final int MIN_PERTURB = -10;
	private final int MAX_PERTURB = 10;
	private int colourMeter;
	private final int MAX_RGB_VAL = 256;

	private int widthOfDrawingRegion;
	private int heightOfDrawingRegion;

	/**
	 * Creates a basic sprite within a game world with the specified dimensions.
	 * 
	 * @param widthOfDrawingRegion
	 *            as described above
	 * @param heightOfDrawingRegion
	 *            as described above
	 */
	public BasicSprite(int widthOfDrawingRegion, int heightOfDrawingRegion) {
		this.widthOfDrawingRegion = widthOfDrawingRegion;
		this.heightOfDrawingRegion = heightOfDrawingRegion;
		// initialize the attributes of the shape to be drawn on each frame
		anchorPoint = new Point(0, 0);
		dot = new Ellipse2D.Double(anchorPoint.x, anchorPoint.y, DIA, DIA);
		colourMeter = 0;
	}

	public void draw(Graphics2D graphics2D) {
		colourMeter++;
		Color theColor = new Color(colourMeter % MAX_RGB_VAL, colourMeter
				% MAX_RGB_VAL, colourMeter % MAX_RGB_VAL);
		graphics2D.setPaint(theColor);
		dot = new Ellipse2D.Double(anchorPoint.x, anchorPoint.y, DIA, DIA);
		graphics2D.fill(dot);

	}

	public void move() {
		int horizontalPerturbValue = UtilityClass.getRandomValue(MIN_PERTURB,
				MAX_PERTURB);
		int verticalPerturbValue = UtilityClass.getRandomValue(MIN_PERTURB,
				MAX_PERTURB);
		int newX = (anchorPoint.x + 1 + horizontalPerturbValue)
				% widthOfDrawingRegion;
		int newY = (anchorPoint.y + 1 + verticalPerturbValue)
				% heightOfDrawingRegion;
		anchorPoint = new Point(newX, newY);
	}

}
